@@ -6,6 +6,7 @@ from environs import Env
 
 HIDDEN_CONFIG = [
     "DIRECTOR_ENABLE_DARK_THEME",
+    "DIRECTOR_ENABLE_HISTORY_MODE",
     "DIRECTOR_API_URL",
     "DIRECTOR_FLOWER_URL",
     "DIRECTOR_DATABASE_URI",
@@ -32,13 +33,14 @@ class Config(object):
         env.read_env(env_path)
 
         self.ENABLE_DARK_THEME = env.bool("DIRECTOR_ENABLE_DARK_THEME", False)
+        self.ENABLE_HISTORY_MODE = env.bool("DIRECTOR_ENABLE_HISTORY_MODE", False)
         self.ENABLE_CDN = env.bool("DIRECTOR_ENABLE_CDN", True)
         self.STATIC_FOLDER = env.str(
             "DIRECTOR_STATIC_FOLDER", str(Path(self.DIRECTOR_HOME).resolve() / "static")
         )
         self.API_URL = env.str("DIRECTOR_API_URL", "http://127.0.0.1:8000/api")
         self.FLOWER_URL = env.str("DIRECTOR_FLOWER_URL", "http://127.0.0.1:5555")
-        self.WORKFLOWS_PER_PAGE = env.int("WORKFLOWS_PER_PAGE", 1000)
+        self.WORKFLOWS_PER_PAGE = env.int("DIRECTOR_WORKFLOWS_PER_PAGE", 1000)
 
         # Authentication
         self.AUTH_ENABLED = env.bool("DIRECTOR_AUTH_ENABLED", False)
